@@ -270,8 +270,7 @@ async def on_message(message):
                     voice_object = await channel_to_connnect_to.connect()
                     if command_dict[c]["source_to_play"] == None:
                         if link_given != True:
-                            print(
-                                "Bot will not play audio because no source file was given.")
+                            await message.channel.send("Please give a YouTube link to play, then try again.")
                             return
 
 
